**Installation**
    `pip install middleware-office-vibe`

Requires `middleware_test`

**Initialization**
    `office_vibe_init` -- creates base OfficeVibe class and record in db with system.
    You can override the common methods in class with own requests or use default ones.